pub struct Account {
pub id: UserId,
pub login: String,
pub account_type: TargetType,
pub avatar_url: Option<String>,
pub html_url: String,
}Expand description
Account information for installations.
Similar to User but represents the account where a GitHub App is installed. This can be either an organization or a user account.
Fields
id: UserIdlogin: Stringaccount_type: TargetTypeavatar_url: Option<String>html_url: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Account
impl<'de> Deserialize<'de> for Account
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for Account