CreateReleaseRequest

Struct CreateReleaseRequest 

pub struct CreateReleaseRequest {
    pub tag_name: String,
    pub target_commitish: Option<String>,
    pub name: Option<String>,
    pub body: Option<String>,
    pub draft: Option<bool>,
    pub prerelease: Option<bool>,
    pub generate_release_notes: Option<bool>,
}
Request to create a release.

Fields

tag_name: String

Tag name (required)

target_commitish: Option<String>

Target commitish (branch or commit SHA)

name: Option<String>

Release name

body: Option<String>

Release body (Markdown)

draft: Option<bool>

Whether to create as draft

prerelease: Option<bool>

Whether to mark as prerelease

generate_release_notes: Option<bool>

Whether to automatically generate the name and body for this release.

When set to true, GitHub will auto-generate the release name (if name is not provided) and the release notes body from merged pull requests and other repository activity since the previous release. If name is provided it is used as-is; if body is provided it is pre-pended to the generated notes. Defaults to false.

Example

use github_bot_sdk::client::CreateReleaseRequest;

let request = CreateReleaseRequest {
    tag_name: "v1.2.0".to_string(),
    target_commitish: None,
    name: None,
    body: None,
    draft: None,
    prerelease: None,
    generate_release_notes: Some(true),
};