pub struct InstallationId(/* private fields */);Expand description
GitHub App installation identifier for specific accounts.
When a GitHub App is installed on an organization or user account, GitHub assigns an installation ID. This ID is used to obtain installation tokens and perform operations on behalf of that installation.
Examples
use github_bot_sdk::auth::InstallationId;
let installation = InstallationId::new(98765);
assert_eq!(installation.as_u64(), 98765);Implementations